@@ -4,7 +4,6 @@ import os
 
 import requests
 import six
-from hdx.utilities.downloader import Download
 from hdx.utilities.email import Email
 from hdx.utilities.session import get_session
 from hdx.utilities.useragent import UserAgent, UserAgentError
@@ -174,6 +173,7 @@ class Configuration(UserDict, object):
         hdx_url = kwargs.get('hdx_url', self.data.get('hdx_url'))
         if hdx_url:
             self.hdx_site = 'hdx_custom_site'
+            hdx_url = hdx_url.rstrip('/')
             self.data[self.hdx_site] = {'url': hdx_url}
         else:
             self.hdx_site = 'hdx_%s_site' % kwargs.get('hdx_site', self.data.get('hdx_site', 'test'))
@@ -241,6 +241,20 @@ class Configuration(UserDict, object):
         """
         return self.data[self.hdx_site]['url']
 
+    def get_dataset_url(self, name):
+        # type: (str) -> str
+        """
+        Return HDX dataset url given dataset name
+
+        Args:
+            name: Dataset name
+
+        Returns:
+            str: HDX dataset url
+
+        """
+        return '%s/dataset/%s' % (self.get_hdx_site_url(), name)
+
     def _get_credentials(self):
         # type: () -> Optional[Tuple[str, str]]
         """
@@ -270,19 +284,6 @@ class Configuration(UserDict, object):
             raise ConfigurationError('There is no remote CKAN set up! Use Configuration.create(**kwargs)')
         return self._remoteckan
 
-    def downloader(self):
-        # type: () -> Download
-        """
-        Return the Download object (see HDX Python Utilities library)
-
-        Returns:
-            Download: The Download object
-
-        """
-        if self._downloader is None:
-            raise ConfigurationError('There is no Download object set up! Use Configuration.create(**kwargs)')
-        return self._downloader
-
     def call_remoteckan(self, *args, **kwargs):
         # type: (Any, Any) -> Dict
         """
@@ -336,8 +337,8 @@ class Configuration(UserDict, object):
 
     @classmethod
     def create_remoteckan(cls, site_url, user_agent=None, user_agent_config_yaml=None, user_agent_lookup=None,
-                          session=None, **kwargs):
-        # type: (str, Optional[str], Optional[str], Optional[str], requests.Session, Any) -> ckanapi.RemoteCKAN
+                          use_env=False, session=None, **kwargs):
+        # type: (str, Optional[str], Optional[str], Optional[str], bool, requests.Session, Any) -> ckanapi.RemoteCKAN
         """
         Create remote CKAN instance from configuration
 
@@ -346,6 +347,7 @@ class Configuration(UserDict, object):
             user_agent (Optional[str]): User agent string. HDXPythonLibrary/X.X.X- is prefixed.
             user_agent_config_yaml (Optional[str]): Path to YAML user agent configuration. Ignored if user_agent supplied. Defaults to ~/.useragent.yml.
             user_agent_lookup (Optional[str]): Lookup key for YAML. Ignored if user_agent supplied.
+            use_env (bool): Whether to read environment variables. Defaults to False.
             session (requests.Session): requests Session object to use. Defaults to calling hdx.utilities.session.get_session()
 
         Returns:
@@ -353,9 +355,9 @@ class Configuration(UserDict, object):
 
         """
         if not session:
-            session = get_session(user_agent, user_agent_config_yaml, user_agent_lookup, prefix=Configuration.prefix,
-                                  method_whitelist=frozenset(['HEAD', 'TRACE', 'GET', 'POST', 'PUT',
-                                                              'OPTIONS', 'DELETE']), **kwargs)
+            whitelist = frozenset(['HEAD', 'TRACE', 'GET', 'POST', 'PUT', 'OPTIONS', 'DELETE'])
+            session = get_session(user_agent, user_agent_config_yaml, user_agent_lookup, use_env,
+                                  prefix=Configuration.prefix, method_whitelist=whitelist, **kwargs)
             ua = session.headers['User-Agent']
         else:
             ua = kwargs.get('full_agent')
